@@ -2,7 +2,7 @@
 /*! @file inkf
     @brief yet another nkf with international language support
     @author Masashi Astro Tachibana
-    @date 2002-2018
+    @date 2002-2019
  ******************************************************************************/
 
 #include <stdio.h>
@@ -17,8 +17,8 @@ using namespace apolloron;
 
 const char *INKF_PROGNAME = "inkf";
 const char *INKF_BRIEF    = "Yet Another Network Kanji Filter";
-const char *INKF_VERSION  = "2.0.5";
-const char *INKF_COPY     = "Copyright (C) 2002-2018 Masashi Astro Tachibana";
+const char *INKF_VERSION  = "2.0.7";
+const char *INKF_COPY     = "Copyright (C) 2002-2019 Masashi Astro Tachibana";
 const char *INKF_DEF_OUT  = "inkf.out";
 
 typedef enum {
@@ -650,6 +650,8 @@ void guess(const String &str, const char *input_charset, FILE *fpout) {
             charcode = "BIG5";
         } else if (!strcmp(charcode, "GB18030")) {
             charcode = "GB2312";
+        } else if (!strcmp(charcode, "CP1252")) {
+            charcode = "Windows-1252";
         }
     } else {
         charcode = input_charset;
