@@ -1260,7 +1260,7 @@ const TTime &DateTime::getTime() const {
     @param void
     @return GMT offset (seconds)
  */
-long DateTime::getGmtOff() const {
+long DateTime::getGMTOffset() const {
     return (*this).tmpDateTime.gmtoff;
 }
 
