@@ -41,6 +41,10 @@ extern const char *STR_CP1252;
 extern const char *STR_UTF8;
 extern const char *STR_UTF7;
 extern const char *STR_UTF7_IMAP;
+extern const char *STR_UTF16LE;
+extern const char *STR_UTF16BE;
+extern const char *STR_UTF32LE;
+extern const char *STR_UTF32BE;
 extern const char *STR_SJIS;
 extern const char *STR_JIS;
 extern const char *STR_EUCJP;
@@ -57,6 +61,10 @@ char* iso8859_to_utf8(const char* str, int iso8859_num);
 char* utf8_to_iso8859(const char* str, int iso8859_num);
 char* europe_to_utf8(const char* str, char ch);
 char* utf8_to_europe(const char* str, char ch);
+char* utf8_to_utf16(const char *str, long *length, char en='L');
+char* utf16_to_utf8(const char *str, long length, char en='L');
+char* utf8_to_utf32(const char *str, long *length, char en='L');
+char* utf32_to_utf8(const char *str, long length, char en='L');
 char* utf8_to_eucjp(const char* str);
 char* sjis_to_eucjp(const char* str);
 char* jis_to_eucjp(const char* str);
