@@ -41,7 +41,7 @@ using namespace apolloron;
 
 int sendn(int sd, const char *buf, int len, int flags);
 int ftp_send_command(LIBOFTP *ftp, const char *cmd);
-int ftp_receive_response(LIBOFTP *ftp, char *res_buf, int bufsiz);
+int ftp_receive_response(LIBOFTP *ftp, char *res_buf, long bufsiz);
 int ftp_getready_active(LIBOFTP *ftp, const char *cmd, const char *fname);
 int ftp_getready_pasv(LIBOFTP *ftp, const char *cmd, const char *fname);
 
@@ -57,7 +57,7 @@ int snprintf( char *, int, char *, ... );
  *@param  flags  flags of recv()
  *@retval  int  number of bytes received, or -1 if an error.
  */
-static int recv_line(int sd, char *buf, int bufsiz, int flags) {
+static int recv_line(int sd, char *buf, long bufsiz, int flags) {
     int n;
     char c;
     char *p = buf;
@@ -143,7 +143,7 @@ int ftp_send_command(LIBOFTP *ftp, const char *cmd) {
  *@note
  * set reply code to ftp attribute reply_code;
  */
-int ftp_receive_response(LIBOFTP *ftp, char *res_buf, int bufsiz) {
+int ftp_receive_response(LIBOFTP *ftp, char *res_buf, long bufsiz) {
     char str1[256];
     int n;
 
@@ -528,7 +528,7 @@ static int ftp_put_file_main(LIBOFTP *ftp, const char *local_fname, const char *
  *@param    bufsiz size of buffer
  *@retval   int    receive size (byte), error code if minus
  */
-static int ftp_get_buffer_main(LIBOFTP *ftp, const char *cmd, const char *fname, char *buf, int bufsiz) {
+static int ftp_get_buffer_main(LIBOFTP *ftp, const char *cmd, const char *fname, char *buf, long bufsiz) {
     int data_socket;
     char *p = buf;
     int res;
@@ -622,10 +622,10 @@ static int ftp_get_buffer_main(LIBOFTP *ftp, const char *cmd, const char *fname,
  *@param    dup_buf[out]  pointor to buffer (need free if not NULL)
  *@retval   int    receive size (byte), error code if minus
  */
-static int ftp_get_buffer_dup_main(LIBOFTP *ftp, const char *cmd, const char *fname, char **dup_buf) {
+static int ftp_get_buffer_dup_main(LIBOFTP *ftp, const char *cmd, const char *fname, char **dup_buf, long *dup_buf_size) {
     int data_socket;
     char tmp_buf[TRANSFER_SEGMENT_SIZE+1];
-    int dup_buf_size = 0;
+    long size = 0;
     int res;
 
     if (dup_buf == NULL ) return FTP_ERROR;
@@ -663,7 +663,7 @@ static int ftp_get_buffer_dup_main(LIBOFTP *ftp, const char *cmd, const char *fn
         if (n == 0) {
             break;
         }
-        p = new char [dup_buf_size + n + 1];
+        p = new char [size + n + 1];
         if (p == NULL) {
             ret = FTP_ERROR_OS;
             copy_strerror();
@@ -674,12 +674,12 @@ static int ftp_get_buffer_dup_main(LIBOFTP *ftp, const char *cmd, const char *fn
             }
             return ret;
         }
-        memcpy(p, (*dup_buf), dup_buf_size);
+        memcpy(p, (*dup_buf), size);
         delete [] (*dup_buf);
         *dup_buf = p;
-        memcpy((*dup_buf) + dup_buf_size, tmp_buf, n);
-        dup_buf_size += n;
-        (*dup_buf)[dup_buf_size] = '\0';
+        memcpy((*dup_buf) + size, tmp_buf, n);
+        size += n;
+        (*dup_buf)[size] = '\0';
     }
 
     /* alright */
@@ -692,7 +692,9 @@ static int ftp_get_buffer_dup_main(LIBOFTP *ftp, const char *cmd, const char *fn
         return res < 0? res: FTP_ERROR_PROTOCOL;
     }
 
-    return dup_buf_size;
+    if (dup_buf_size != NULL) *dup_buf_size = size;
+
+    return FTP_NOERROR;
 }
 
 
@@ -1155,7 +1157,7 @@ int ftp_rename(LIBOFTP *ftp, const char *from, const char *to) {
  *@param    bufsiz size of buffer
  *@retval   int    size(byte) or error code if minus
  */
-int ftp_get_buffer(LIBOFTP *ftp, const char *fname, char *buf, int bufsiz) {
+int ftp_get_buffer(LIBOFTP *ftp, const char *fname, char *buf, long bufsiz) {
     return ftp_get_buffer_main(ftp, "RETR", fname, buf, bufsiz);
 }
 
@@ -1166,8 +1168,8 @@ int ftp_get_buffer(LIBOFTP *ftp, const char *fname, char *buf, int bufsiz) {
  *@param    dup_buf[out]  pointor to buffer (need free if not NULL)
  *@retval   int    size(byte) or error code if minus
  */
-int ftp_get_buffer_dup(LIBOFTP *ftp, const char *fname, char **dup_buf) {
-    return ftp_get_buffer_dup_main(ftp, "RETR", fname, dup_buf);
+int ftp_get_buffer_dup(LIBOFTP *ftp, const char *fname, char **dup_buf, long *dup_buf_size) {
+    return ftp_get_buffer_dup_main(ftp, "RETR", fname, dup_buf, dup_buf_size);
 }
 
 
@@ -1179,7 +1181,7 @@ int ftp_get_buffer_dup(LIBOFTP *ftp, const char *fname, char **dup_buf) {
  *@param    cmd    FTP command to send
  *@retval   int    error code
  */
-static int ftp_put_buffer_main(LIBOFTP *ftp, const char *buf, int bufsiz, const char *fname, const char *cmd) {
+static int ftp_put_buffer_main(LIBOFTP *ftp, const char *buf, long bufsiz, const char *fname, const char *cmd) {
     int data_socket;
     const char *p = buf;
     int n, res;
@@ -1239,7 +1241,7 @@ static int ftp_put_buffer_main(LIBOFTP *ftp, const char *buf, int bufsiz, const
  *@param    fname  filename on server
  *@retval   int    error code
  */
-int ftp_put_buffer( LIBOFTP *ftp, const char *buf, int bufsiz, const char *fname) {
+int ftp_put_buffer( LIBOFTP *ftp, const char *buf, long bufsiz, const char *fname) {
     return ftp_put_buffer_main( ftp, buf, bufsiz, fname, "STOR");
 }
 
@@ -1251,7 +1253,7 @@ int ftp_put_buffer( LIBOFTP *ftp, const char *buf, int bufsiz, const char *fname
  *@param    fname  filename on server
  *@retval   int    error code
  */
-int ftp_append_buffer(LIBOFTP *ftp, const char *buf, int bufsiz, const char *fname) {
+int ftp_append_buffer(LIBOFTP *ftp, const char *buf, long bufsiz, const char *fname) {
     return ftp_put_buffer_main(ftp, buf, bufsiz, fname, "APPE");
 }
 
@@ -1477,7 +1479,7 @@ int ftp_append_descriptor_close(LIBOFTP *ftp, int desc) {
  *@param    bufsiz size of buffer
  *@retval   int    error code
  */
-int ftp_list(LIBOFTP *ftp, const char *fglob, char *buf, int bufsiz) {
+int ftp_list(LIBOFTP *ftp, const char *fglob, char *buf, long bufsiz) {
     int ret;
 
     ret = ftp_get_buffer_main(ftp, "LIST", fglob, buf, bufsiz);
@@ -1496,13 +1498,10 @@ int ftp_list(LIBOFTP *ftp, const char *fglob, char *buf, int bufsiz) {
  *@param    dup_buf[out]  pointor to buffer (need free if not NULL)
  *@retval   int    error code
  */
-int ftp_list_dup(LIBOFTP *ftp, const char *fglob, char **dup_buf) {
+int ftp_list_dup(LIBOFTP *ftp, const char *fglob, char **dup_buf, long *dup_buf_size) {
     int ret;
 
-    ret = ftp_get_buffer_dup_main(ftp, "LIST", fglob, dup_buf);
-    if (0 < ret) {
-        return FTP_NOERROR;
-    }
+    ret = ftp_get_buffer_dup_main(ftp, "LIST", fglob, dup_buf, dup_buf_size);
 
     return ret;
 }
@@ -1515,7 +1514,7 @@ int ftp_list_dup(LIBOFTP *ftp, const char *fglob, char **dup_buf) {
  *@param    bufsiz size of buffer
  *@retval   int    error code
  */
-int ftp_nlist(LIBOFTP *ftp, const char *fglob, char *buf, int bufsiz ) {
+int ftp_nlist(LIBOFTP *ftp, const char *fglob, char *buf, long bufsiz ) {
     int ret;
 
     ret = ftp_get_buffer_main(ftp, "NLST", fglob, buf, bufsiz);
@@ -1534,13 +1533,10 @@ int ftp_nlist(LIBOFTP *ftp, const char *fglob, char *buf, int bufsiz ) {
  *@param    dup_buf[out]  pointor to buffer (need free if not NULL)
  *@retval   int    error code
  */
-int ftp_nlist_dup(LIBOFTP *ftp, const char *fglob, char **dup_buf) {
+int ftp_nlist_dup(LIBOFTP *ftp, const char *fglob, char **dup_buf, long *dup_buf_size) {
     int ret;
 
-    ret = ftp_get_buffer_dup_main(ftp, "NLST", fglob, dup_buf);
-    if (0 < ret) {
-        return FTP_NOERROR;
-    }
+    ret = ftp_get_buffer_dup_main(ftp, "NLST", fglob, dup_buf, dup_buf_size);
 
     return ret;
 }
@@ -1612,7 +1608,7 @@ int ftp_rmdir(LIBOFTP *ftp, const char *dirname) {
  *@param    bufsiz  buffer size
  *@retval   int     error code
  */
-int ftp_pwd(LIBOFTP *ftp, char *buf, int bufsiz) {
+int ftp_pwd(LIBOFTP *ftp, char *buf, long bufsiz) {
     char str1[512] = "PWD\r\n";
     int res;
     char *p1, *p2;
