@@ -752,7 +752,7 @@ std::string JSONReader::getLocationLineAndColumn(Location location) const {
     int line, column;
     getLocationLineAndColumn(location, line, column);
     char buffer[18 + 16 + 16 + 1];
-    sprintf(buffer, "Line %d, Column %d", line, column);
+    ::snprintf(buffer, sizeof(buffer), "Line %d, Column %d", line, column);
     return buffer;
 }
 
